package com.ruoyi.bst.help.mapper;

import java.util.List;
import com.ruoyi.bst.help.domain.Help;
import com.ruoyi.bst.help.domain.HelpVO;
import com.ruoyi.bst.help.domain.HelpQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 教程列表Mapper接口
 *
 * @author ruoyi
 * @date 2025-04-29
 */
public interface HelpMapper
{
    /**
     * 查询教程列表
     *
     * @param id 教程列表主键
     * @return 教程列表
     */
    HelpVO selectHelpById(Long id);

    /**
     * 查询教程列表列表
     *
     * @param query 教程列表
     * @return 教程列表集合
     */
    List<HelpVO> selectHelpList(@Param("query")HelpQuery query);

    /**
     * 新增教程列表
     *
     * @param help 教程列表
     * @return 结果
     */
    int insertHelp(Help help);

    /**
     * 批量新增教程列表
     */
    int batchInsert(@Param("list") List<? extends Help> list);

    /**
     * 批量修改教程列表
     */
    int batchUpdate(@Param("list") List<? extends Help> list);

    /**
     * 修改教程列表
     *
     * @param help 教程列表
     * @return 结果
     */
    public int updateHelp(@Param("data") Help help);

    /**
     * 删除教程列表
     *
     * @param id 教程列表主键
     * @return 结果
     */
    int deleteHelpById(Long id);

    /**
     * 批量删除教程列表
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHelpByIds(Long[] ids);
}
